@@ -3,7 +3,10 @@ from enum import Enum
 from pathlib import Path 
 
 import nltk
-nltk.data.path.append(f"{Path(__file__).parent}/corpora")
+
+DATA_PATH = f"{Path(__file__).parent}/nltk_data/corpora"
+if DATA_PATH not in nltk.data.path:
+    nltk.data.path.append(DATA_PATH)
 
 from nltk.corpus import stopwords, wordnet
 from nltk.corpus.reader.wordnet import Synset
